asr.test.test\_borncharges
==========================

.. automodule:: asr.test.test_borncharges

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_borncharges
   
   

   
   
   

   
   
   